@@ -626,6 +626,41 @@ class BezierPath(BooleanOperationsMixin,SampleMixin,object):
         segs[i] = s.toCubicBezier()
     return self
 
+  def thicknessAtX(path, x):
+    """Returns the thickness of the path at x-coordinate ``x``."""
+    bounds = path.bounds()
+    bounds.addMargin(10)
+    ray = Line(Point(x - 0.1, bounds.bottom), Point(x + 0.1, bounds.top))
+    intersections = []
+    for seg in path.asSegments():
+      intersections.extend(seg.intersections(ray))
+    if len(intersections) < 2:
+      return None
+    intersections = list(sorted(intersections, key=lambda i: i.point.y))
+    i1, i2 = intersections[0:2]
+    inorm1 = i1.seg1.normalAtTime(i1.t1)
+    ray1 = Line(i1.point + (inorm1 * 1000), i1.point + (inorm1 * -1000))
+    iii = i2.seg1.intersections(ray1)
+    if iii:
+      ll1 = i1.point.distanceFrom(iii[0].point)
+    else:
+      # Simple, vertical version
+      return abs(i1.point.y - i2.point.y)
+
+    inorm2 = i2.seg1.normalAtTime(i2.t1)
+    ray2 = Line(i2.point + (inorm2 * 1000), i2.point + (inorm2 * -1000))
+    iii = i1.seg1.intersections(ray2)
+    if iii:
+      ll2 = i2.point.distanceFrom(iii[0].point)
+      return (ll1 + ll2) * 0.5
+    else:
+      return ll1
+
+    # midpoint = (i1.point + i2.point) / 2
+    # # Find closest path to midpoint
+    # # Find the tangent at that time
+    # inorm2 = i2.seg1.normalAtTime(i2.t1)
+
   def distanceToPath(self, other, samples = 10):
     """Finds the distance to the other curve at its closest point,
     along with the t values for the closest point at each segment
@@ -705,7 +740,7 @@ class BezierPath(BooleanOperationsMixin,SampleMixin,object):
             last = collection[-1]
             if abs(last.tangentAtTime(1).angle - s.tangentAtTime(0).angle) > math.radians(cornerTolerance):
               corner = True
-          if len(collection) > maxCollectionSize or corner or i == len(segs)-1:
+          if len(collection) > maxCollectionSize or corner or i == len(segs)-2:
             points = [x.start for x in collection]
             bp = BezierPath.fromPoints(points)
             if len(bp.asSegments()) > 0:
@@ -713,6 +748,11 @@ class BezierPath(BooleanOperationsMixin,SampleMixin,object):
               i -= len(collection)
             collection = []
         i += 1
+    if len(collection) > 0:
+      points = [x.start for x in collection]
+      bp = BezierPath.fromPoints(points)
+      if len(bp.asSegments()) > 0:
+        segs[i-(1+len(collection)):i-1] = bp.asSegments()
 
     self.activeRepresentation = SegmentRepresentation(self, segs)
     return self
\ No newline at end of file
